import { _getReferencesFromScripts } from '../../util/binaries/index.js';
import { _firstGlob } from '../../util/glob.js';
import { _load } from '../../util/loader.js';
import { getValuesByKeyDeep } from '../../util/object.js';
import { timerify } from '../../util/performance.js';
export const NAME = 'GitHub Actions';
export const ENABLERS = 'This plugin is enabled when a `.yml` file is found in the `.github/workflows` folder.';
export const isEnabled = async ({ cwd }) => Boolean(await _firstGlob({ cwd, patterns: ['.github/workflows/*.yml'] }));
export const CONFIG_FILE_PATTERNS = ['.github/workflows/*.yml', '.github/**/action.{yml,yaml}'];
const findGithubActionsDependencies = async (configFilePath, { cwd, manifest, rootConfig }) => {
    const config = await _load(configFilePath);
    if (!config)
        return [];
    const scripts = getValuesByKeyDeep(config, 'run').filter((value) => typeof value === 'string');
    const { binaries, entryFiles } = _getReferencesFromScripts(scripts, {
        cwd,
        manifest,
        ignore: rootConfig.ignoreBinaries,
        knownGlobalsOnly: true,
    });
    return { dependencies: binaries, entryFiles };
};
export const findDependencies = timerify(findGithubActionsDependencies);
