import { _getReferencesFromScripts } from '../../util/binaries/index.js';
import { _load } from '../../util/loader.js';
import { timerify } from '../../util/performance.js';
import { hasDependency } from '../../util/plugin.js';
export const NAME = 'lint-staged';
export const ENABLERS = ['lint-staged'];
export const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
export const CONFIG_FILE_PATTERNS = [
    '.lintstagedrc',
    '.lintstagedrc.json',
    '.lintstagedrc.{yml,yaml}',
    '.lintstagedrc.{js,mjs,cjs}',
    'lint-staged.config.{js,mjs,cjs}',
    'package.json',
];
const findLintStagedDependencies = async (configFilePath, { cwd, manifest, rootConfig }) => {
    let config = configFilePath.endsWith('package.json')
        ? manifest['lint-staged']
        : await _load(configFilePath);
    if (!config)
        return [];
    if (typeof config === 'function') {
        config = config();
    }
    const binaries = new Set();
    for (const entry of Object.values(config).flat()) {
        const scripts = [typeof entry === 'function' ? await entry([]) : entry].flat();
        const options = { cwd, manifest, ignore: rootConfig.ignoreBinaries };
        _getReferencesFromScripts(scripts, options).binaries.forEach(bin => binaries.add(bin));
    }
    return Array.from(binaries);
};
export const findDependencies = timerify(findLintStagedDependencies);
