import parse from 'bash-parser';
import parseArgs from 'minimist';
import * as FallbackResolver from './resolvers/fallback.js';
import * as KnownResolvers from './resolvers/index.js';
const spawningBinaries = ['cross-env', 'dotenv'];
export const getBinariesFromScript = (script, { cwd, manifest, knownGlobalsOnly = false }) => {
    const findByArgs = (args) => (args.length > 0 ? findBinaries(parse(args.join(' ')).commands) : []);
    const findBinaries = (items) => items.flatMap(item => {
        switch (item.type) {
            case 'Command': {
                const binary = item.name?.text;
                if (!binary || binary === '.' || binary === 'source')
                    return [];
                if (binary.startsWith('-') || binary.startsWith('"') || binary.startsWith('..'))
                    return [];
                if (['bun', 'deno'].includes(binary))
                    return [];
                const args = item.suffix?.map(arg => arg.text) ?? [];
                if (['!', 'test'].includes(binary))
                    return findByArgs(args);
                if (binary in KnownResolvers) {
                    return KnownResolvers[binary].resolve(binary, args, cwd, manifest, (args) => {
                        const [binary, ...rest] = args;
                        return FallbackResolver.resolve(binary, rest, cwd);
                    });
                }
                if (knownGlobalsOnly)
                    return [];
                if (spawningBinaries.includes(binary)) {
                    const parsedArgs = parseArgs(args);
                    const [spawnedBinary] = parsedArgs._;
                    if (spawnedBinary) {
                        const restArgs = args.slice(args.indexOf(spawnedBinary));
                        return [binary, ...findByArgs(restArgs)];
                    }
                    else {
                        return [];
                    }
                }
                return FallbackResolver.resolve(binary, args, cwd);
            }
            case 'LogicalExpression':
                return findBinaries([item.left, item.right]);
            case 'If':
                return findBinaries([...item.clause.commands, ...item.then.commands]);
            case 'For':
                return findBinaries(item.do.commands);
            default:
                return [];
        }
    });
    const parsed = parse(script);
    return parsed?.commands ? findBinaries(parsed.commands) : [];
};
