import path from 'node:path';
import parseArgs from 'minimist';
import { tryResolve } from '../../require.js';
const resolveArguments = {
    'ts-node': (parsed) => [parsed._[0], parsed.require].flat(),
    tsx: (parsed) => parsed._.filter(p => p !== 'watch'),
    default: (parsed) => [parsed.require].flat(),
};
export const resolve = (binary, args, cwd) => {
    const parsed = parseArgs(args, { string: ['r'], alias: { require: ['r', 'loader'] } });
    const resolver = resolveArguments[binary] ?? resolveArguments.default;
    const resolve = resolver(parsed);
    return [
        binary,
        ...resolve.flatMap(specifier => {
            if (specifier) {
                const filePath = path.join(cwd, specifier);
                if (filePath.startsWith(cwd)) {
                    const resolvedFilePath = tryResolve(filePath);
                    if (resolvedFilePath)
                        return [resolvedFilePath];
                }
                return [specifier];
            }
            return [];
        }),
    ];
};
