import { InstalledBinaries, PeerDependencies } from './types/workspace.js';
import type { Configuration, PluginConfiguration, PluginName, WorkspaceConfiguration } from './types/config.js';
import type { Issue } from './types/issues.js';
import type { PackageJson } from 'type-fest';
type WorkspaceManagerOptions = {
    name: string;
    dir: string;
    config: WorkspaceConfiguration;
    manifest: PackageJson;
    rootWorkspaceConfig: WorkspaceConfiguration;
    rootConfig: Configuration;
    negatedWorkspacePatterns: string[];
    rootWorkspaceDir: string;
    isProduction: boolean;
};
type ReferencedDependencyIssues = Set<Issue>;
export default class WorkspaceWorker {
    name: string;
    dir: string;
    config: WorkspaceConfiguration;
    rootWorkspaceConfig: WorkspaceConfiguration;
    rootConfig: Configuration;
    manifest: PackageJson;
    rootWorkspaceDir: string;
    referencedDependencyIssues: ReferencedDependencyIssues;
    peerDependencies: PeerDependencies;
    installedBinaries: InstalledBinaries;
    entryFiles: Set<string>;
    negatedWorkspacePatterns: string[];
    enabled: Record<PluginName, boolean>;
    enabledPlugins: PluginName[];
    isRoot: boolean;
    isProduction: boolean;
    constructor({ name, dir, config, rootWorkspaceConfig, rootConfig, negatedWorkspacePatterns, manifest, rootWorkspaceDir, isProduction, }: WorkspaceManagerOptions);
    getConfigForPlugin(pluginName: PluginName): PluginConfiguration;
    setEnabledPlugins(enabledPluginsInAncestors: string[]): Promise<void>;
    initReferencedDependencies(): Promise<void>;
    getEntryFilePatterns(): string[];
    getProjectFilePatterns(): string[];
    getPluginEntryFilePatterns(isIncludeProductionEntryFiles?: boolean): string[];
    getPluginProjectFilePatterns(): string[];
    getPluginConfigPatterns(): string[];
    getProductionEntryFilePatterns(): string[];
    getProductionProjectFilePatterns(): string[];
    getProductionPluginEntryFilePatterns(): string[];
    getConfigurationEntryFilePattern(pluginName: PluginName): string[];
    getWorkspaceIgnorePatterns(): string[];
    findDependenciesByPlugins(): Promise<void>;
    getFinalDependencies(): {
        peerDependencies: PeerDependencies;
        installedBinaries: InstalledBinaries;
        referencedDependencyIssues: ReferencedDependencyIssues;
        entryFiles: Set<string>;
        enabledPlugins: ("babel" | "capacitor" | "changesets" | "commitlint" | "cypress" | "eslint" | "gatsby" | "husky" | "jest" | "markdownlint" | "mocha" | "next" | "nx" | "nyc" | "playwright" | "postcss" | "prettier" | "remark" | "remix" | "rollup" | "sentry" | "storybook" | "stryker" | "typescript" | "vitest" | "webpack" | "githubActions" | "lintStaged" | "npmPackageJsonLint" | "releaseIt")[];
    };
}
export {};
